summaryrefslogtreecommitdiff
path: root/internal/cli/flags.go
diff options
context:
space:
mode:
Diffstat (limited to 'internal/cli/flags.go')
-rw-r--r--internal/cli/flags.go9
1 files changed, 5 insertions, 4 deletions
diff --git a/internal/cli/flags.go b/internal/cli/flags.go
index b9d28c9..104f721 100644
--- a/internal/cli/flags.go
+++ b/internal/cli/flags.go
@@ -20,10 +20,11 @@ type Flags struct {
ImageAPI string
ImageAPISpecified bool
BatchFile string
- StoryFile string // --story <file>: generate vocabulary story + comic image
- StoryStyle string // --story-style: override the random art style (empty = random)
- StoryTheme string // --story-theme: override the random genre pick (empty = random)
- NarratorVoice string // --narrator-voice: Gemini voice for cinematic narration (empty = random)
+ StoryFile string // --story <file>: generate vocabulary story + comic image
+ StoryStyle string // --story-style: override the random art style (empty = random)
+ StoryTheme string // --story-theme: override the random genre pick (empty = random)
+ StoryNoUltraRealistic bool // --no-ultra-realistic: disable photorealistic rendering requirement
+ NarratorVoice string // --narrator-voice: Gemini voice for cinematic narration (empty = random)
SkipAudio bool
SkipImages bool
GenerateAnki bool